@@ -60,10 +60,14 @@ def main():
 
 
 def setup_couchdb():
+    cmd = ['couchdb', '-couch_ini', os.path.join(HERE, "static", "local.ini")]
+    if os.name == 'nt':
+        cmd = ["cmd.exe", "/c"] + cmd
     return {
         # hardcode port for backend access
-        'command': ['couchdb', '-couch_ini', os.path.join(HERE, "static", "local.ini")],
-        'port': 5984
+        'command': cmd,
+        'port': 5984,
+        'request_headers_override': {"Authorization": "Basic YWRtaW46YWRtaW4="}
     }
 
 def setup_panel():
